import { File } from 'rxline/fs';
import { PartialOptions as MarkdownOptions } from '@connectv/marked';
import { TransportedFunc } from '@connectv/sdh/dist/es6/dynamic/transport/index';
import { CodedocTheme } from './theme';
import { GithubBtnActions } from './components/misc/github';
import { MetaOptions } from './components/page/meta';
import { FontsOptions } from './components/page/fonts';
export interface SourceConfig {
    base: string;
    toc: string;
    notfound: string;
    pick: RegExp;
    drop: RegExp;
}
export interface DestConfig {
    html: string;
    assets: string;
    bundle: string;
    styles: string;
}
export interface BundleConfig {
    init: TransportedFunc<void>[];
}
export interface TitleConfig {
    base: string;
    connector: string;
    extractor: (content: HTMLElement, config: CodedocConfig, file: File<string>) => string;
}
export interface GithubConfig {
    user: string;
    repo: string;
    action?: GithubBtnActions;
    count?: boolean;
    large?: boolean;
    standardIcon?: boolean;
}
export interface GitterConfig {
    room: string;
}
export interface DevConfig {
    port: number;
}
export interface CodedocConfig {
    src: SourceConfig;
    dest: DestConfig;
    bundle: BundleConfig;
    page: {
        title: TitleConfig;
        favicon?: string;
        meta?: MetaOptions;
        fonts?: FontsOptions;
    };
    theme: CodedocTheme;
    markdown: MarkdownOptions<any, any>;
    tocMarkdown: MarkdownOptions<any, any>;
    dev: DevConfig;
    misc?: {
        github?: GithubConfig;
        gitter?: GitterConfig;
        [whatever: string]: any;
    };
}
export declare const DefaultConfig: CodedocConfig;
export interface ConfigOverride {
    src?: Partial<SourceConfig>;
    dest?: Partial<DestConfig>;
    bundle?: Partial<BundleConfig>;
    dev?: Partial<DevConfig>;
    page?: {
        title?: Partial<TitleConfig>;
        favicon?: string;
        meta?: MetaOptions;
        fonts?: FontsOptions;
    };
    theme?: CodedocTheme;
    markdown?: MarkdownOptions<any, any>;
    tocMarkdown?: MarkdownOptions<any, any>;
    misc?: {
        github?: GithubConfig;
        gitter?: GitterConfig;
        [whatevs: string]: any;
    };
}
export declare function configuration(override: ConfigOverride): CodedocConfig;
