import { state, pipe, pin, map, pack, emission, filter } from '@connectv/core';
import { debounceTime, startWith, share } from 'rxjs/operators';
import { ref, List } from '@connectv/html';
import { ToCSearchOverlayStyle } from './style';
import { Loading } from '../../../../util/loading';
export function ToCSearchOverlay(options, renderer) {
    const classes = this.theme.classes(ToCSearchOverlayStyle);
    const holder = ref();
    const input = ref();
    const toc = ref();
    this.track({
        bind() {
            input.$.focus();
            holder.$.classList.add('active');
            toc.resolve(document.getElementById('-codedoc-toc') || renderer.create("fragment", null));
        }
    });
    const query = state('');
    const loading = state(false);
    const queryOut = this.expose.out('query');
    const results = this.expose.in('results', pin())
        .to(pipe(share()))
        .to(pipe(startWith(emission([]))))
        .to(map((links) => {
        const res = links.map(l => ({ link: l, title: tocLinkTitle(l) }));
        if (query.value.length > 0) {
            toc.$.querySelectorAll('a').forEach(a$ => {
                var _a;
                if (((_a = a$.textContent) === null || _a === void 0 ? void 0 : _a.toLowerCase().includes(query.value.toLowerCase())) && a$.getAttribute('href')
                    && !links.includes(a$.getAttribute('href') || ''))
                    res.push({ link: a$.getAttribute('href') || '', title: a$.textContent });
            });
        }
        return res;
    }));
    query
        .to(filter((q) => q && q.trim().length > 0))
        .to(loading.from(map(() => true)), queryOut.from(pipe(debounceTime(1000))));
    results.to(map(() => false)).to(loading);
    const hideEmpty = pack(query, results, loading)
        .to(map(([_query, _results, _loading]) => {
        if (_loading)
            return true;
        else
            return !_query || _query.trim().length == 0 || _results.length > 0;
    }));
    const tocLinkTitle = (link) => { var _a; return ((_a = toc.$.querySelector(`a[href="${link}"]`)) === null || _a === void 0 ? void 0 : _a.textContent) || link; };
    return renderer.create("div", { class: classes.overlay, _ref: holder, onkeydown: event => {
            if (event.key === 'Escape')
                holder.$.remove();
        } },
        renderer.create("div", { class: classes.content },
            renderer.create("div", { class: "top" },
                renderer.create("input", { placeholder: options.placeholder, type: "text", _ref: input, _state: query }),
                renderer.create("div", { class: classes.close, onclick: () => holder.$.remove() })),
            renderer.create("div", { class: classes.results },
                renderer.create("div", { class: "loading", hidden: loading.to(map((_) => !_)) },
                    renderer.create(Loading, null)),
                renderer.create("div", { class: "empty", hidden: hideEmpty }, "No Results!"),
                renderer.create("div", { hidden: loading },
                    renderer.create(List, { of: results, each: result => renderer.create("a", { href: result.sub('link'), onclick: () => {
                                holder.$.remove();
                                window.dispatchEvent(new CustomEvent('on-navigation-search', { detail: { query: query.value } }));
                            } }, result.sub('title')) })))));
}
//# sourceMappingURL=index.js.map